@@ -20,5 +20,7 @@ class MobileBy(By):
     IOS_UIAUTOMATION = '-ios uiautomation'
     IOS_CLASS_CHAIN = '-ios class chain'
     ANDROID_UIAUTOMATOR = '-android uiautomator'
+    ANDROID_VIEWTAG = '-android viewtag'
     ACCESSIBILITY_ID = 'accessibility id'
     IMAGE = '-image'
+    CUSTOM = '-custom'
